use sea_orm_migration::{prelude::*, sea_orm::Iterable};
use crate::db_enums::*;

#[derive(DeriveMigrationName)]
pub struct Migration;

#[async_trait::async_trait]
impl MigrationTrait for Migration {
    async fn up(&self, manager: &SchemaManager) -> Result<(), DbErr> {

        manager.create_type(
            extension::postgres::Type::create()
                .as_enum(Status)
                .values(ConnStatus::iter())
                .to_owned(),
        ).await?;

        manager.alter_table(
            sea_query::Table::alter()
                .table(Locations::Table)
                .add_column_if_not_exists(
                    ColumnDef::new(Locations::Status).enumeration(Status, ConnStatus::iter())
                ).to_owned()
        ).await
    }

    async fn down(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        // Replace the sample below with your own migration scripts
        manager.drop_type(
            extension::postgres::Type::drop()
                .name(Status)
                .to_owned()
        ).await?;

        manager.alter_table(sea_query::Table::alter()
                .table(Locations::Table)
                .drop_column(
                    Locations::Status
                ).to_owned()
        ).await
    }
}

