use serde::{Serialize, Deserialize};

#[derive(Deserialize, Debug, Default, Clone)]
pub struct TelegramMessageEntity {
    pub r#type: String,
    pub length: i64
}

#[derive(Deserialize, Debug, Default, Clone)]
pub struct TelegramChat {
    pub id: i64,
    #[serde(default)]
    pub first_name: String,
    pub last_name: Option<String>,
    #[serde(default)]
    pub username: String,
    pub r#type: String
}

#[derive(Deserialize, Debug, Default, Clone)]
pub struct TelegramUser {
    pub id: i64,
    pub is_bot: bool,
    #[serde(default)]
    pub first_name: String,
    pub last_name: Option<String>,
    #[serde(default)]
    pub username: Option<String>,
    pub language_code: Option<String>,
    pub is_premium: Option<bool>,
    pub added_to_attachment_menu: Option<bool>,
    pub can_join_groups: Option<bool>,
    pub can_read_all_group_messages: Option<bool>,
    pub supports_inline_queries: Option<bool>,
}

#[derive(Deserialize, Debug, Default, Clone)]
pub struct TelegramMessage {
    pub message_id: i64,
    pub from: TelegramUser,
    pub chat: TelegramChat,
    pub date: u32,
    #[serde(default)]
    pub text: String,

}
impl TelegramMessage {

}

#[derive(Deserialize, Debug, Clone)]
pub struct TelegramUpdate {
    pub update_id: i64,
    #[serde(default)]
    pub message: TelegramMessage
}

#[derive(Deserialize, Debug, Clone)]
pub struct TelegramResponce {
    pub ok: bool,
    #[serde(default)]
    pub result: Vec<TelegramUpdate>,
}
#[derive(Serialize, Debug)]
pub struct TelegramKeyboardMarkup {
    pub keyboard: Vec<Vec<String>>,
    pub resize_keyboard: bool,
}

#[derive(Serialize, Debug)]
pub struct TelegramKeyboardButton {
    pub text: String,
    pub request_location: bool
}